#region Copyright  2004-2005 Victor Boctor
//
// MantisConnect is copyrighted to Victor Boctor
//
// This program is distributed under the terms and conditions of the GPL
// See LICENSE file for details.
//
// For commercial applications to link with or modify MantisConnect, they require the
// purchase of a MantisConnect commerical license.
//
#endregion

using System;
using System.Net;
using System.Web.Services.Protocols;

using NUnit.Framework;

namespace Futureware.MantisConnect.UnitTests
{
    /// <summary>
    /// 
    /// </summary>
    [TestFixture]
    public sealed class ProjectVersions : BaseTestFixture
    {
        [TestFixtureSetUp]
        public void TestFixtureSetup()
        {
            Connect();
        }

        [TestFixtureTearDown]
        public void TestFixtureTearDown()
        {
        }

        #region Request.ProjectGetVersions()
        [Test]
        [ExpectedException( typeof( ArgumentOutOfRangeException ) )]
        public void ProjectGetVersionsForInvalidProject()
        {
            Session.Request.ProjectGetVersions( -50 );
        }

        [Test]
        [ExpectedException( typeof( SoapException ) )]
        public void ProjectGetVersionsForNonExistingProject()
        {
            Session.Request.ProjectGetVersions( 99999 );
        }

        [Test]
        public void ProjectGetVersionsForFirstProject()
        {
            int projectId = FirstProjectId;
            if ( projectId == 0 )
                Assert.Ignore();

            Session.Request.ProjectGetVersions( projectId );
        }
        #endregion

        #region Request.ProjectGetReleasedVersions()
        [Test]
        [ExpectedException( typeof( ArgumentOutOfRangeException ) )]
        public void ProjectGetVersionsReleasedForInvalidProject()
        {
            Session.Request.ProjectGetVersionsReleased( -50 );
        }

        [Test]
        [ExpectedException( typeof( SoapException ) )]
        public void ProjectGetVersionsReleasedForNonExistingProject()
        {
            Session.Request.ProjectGetVersionsReleased( 99999 );
        }

        [Test]
        public void ProjectGetVersionsReleasedForFirstProject()
        {
            int projectId = FirstProjectId;
            if ( projectId == 0 )
                Assert.Ignore();

            Session.Request.ProjectGetVersionsReleased( projectId );
        }
        #endregion

        #region Request.ProjectGetUnreleasedVersions()
        [Test]
        [ExpectedException( typeof( ArgumentOutOfRangeException ) )]
        public void ProjectGetVersionsUnreleasedForInvalidProject()
        {
            Session.Request.ProjectGetVersionsUnreleased( -50 );
        }

        [Test]
        [ExpectedException( typeof( SoapException ) )]
        public void ProjectGetVersionsUnreleasedForNonExistingProject()
        {
            Session.Request.ProjectGetVersionsUnreleased( 99999 );
        }

        [Test]
        public void ProjectGetVersionsUnreleasedForFirstProject()
        {
            int projectId = FirstProjectId;
            if ( projectId == 0 )
                Assert.Ignore();

            Session.Request.ProjectGetVersionsUnreleased( projectId );
        }
        #endregion
    }
}
